# Based on Code for waving hand demonstration board.
# N. J. Halse 17-08-18
# using serial commands to an FTDI serial port.
# Modified as a an example test program NJH 03/02/20


import serial    # serial inteface
import time      # used for system timings
import sys       # display of data read back from the board.
import signal    # intercept SIGINT (Ctrl-C) to end demo.

# Define the port, baudrate and timeout (in sec) to use '/dev/ttyUSB0, 9600, timeout=1'
SER_PORT_LIN = '/dev/ttyUSB0'       # Set this to the port that FTDI assigned to the USB4 if running Linux
SER_PORT_WIN = 'COM2'              # Set this to the port that FTDI assigned to the USB4 if running Windows
EDdealy = 0.1                       # Delay after sending a command to the EasyDAQ board to allow for the outputs to be set and the switches to debounce

BUFFER_SIZE = 1 # How many bytes to read back from board

# Introduction
print ("\nEasyDaq USB demonstration of the USB4PRMx board")
print ("(Hit Ctrl-c to end)\n")

# Open port
ser = serial.Serial(SER_PORT_WIN)   # Open the port (select WIN for Windows and LIN for Linux)
print (ser.name)                    # for debug

# Define a signal handler to catch when the user quits using Ctrl-C and then tidy up
def signal_handler(signal, frame):
 print('\n\n\n      *** Thank you for trying the EasyDaq USB4 *** \nFor further information please visit http://www.easydaq.co.uk\n')
 MESSAGE = b'\x43\x00'              # PIC port B to All on
 ser.write(MESSAGE)
 time.sleep(3)
 ser.close()
 sys.exit(0) 

# Define the relay control function
def set_relays(MESSAGE):
 ser.write(MESSAGE)                 # Send the setup data to the EasyDAQ board
 time.sleep(EDdealy)                # Delay to allow EasyDAQ board to switch the relays

signal.signal(signal.SIGINT, signal_handler) # Register the signal handler for the CTRL-C termination of the program

# Define reading port b
def readB():
     MESSAGE = b'\x41\x00'              # Read port B
     set_relays(MESSAGE)
     time.sleep(0.25)
     BYTEIN = ser.read()             # get the byte
     BYTEIN = ord(BYTEIN)
     print ('Input byte ',"%#5.2X"% (BYTEIN),'  ',format(BYTEIN,'#010b'))

# Configure the USB4 ports for input/output
MESSAGE = b'\x42\xF0'               # Set PIC port B lower 4 bits to output, upper 4 bits to I/P
ser.write(MESSAGE)                  # Send the command
time.sleep(EDdealy)                 # Allow the EasyDAQ board time to set the putputs

# The main program loop
while True:
 MESSAGE = b'\x43\x01'              # Set PIC port B, lower 4 bits to 0x01 (Relays 1 on)
 set_relays(MESSAGE)
 time.sleep(0.001)
 readB()
 MESSAGE = b'\x43\x00'              # Set PIC port B, lower 4 bits to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(0.1)
 MESSAGE = b'\x43\x02'              # Set PIC port B, lower 4 bits to 0x02 (Relay 2 on)
 set_relays(MESSAGE)
 time.sleep(0.001)
 readB()
 MESSAGE = b'\x43\x00'              # Set PIC port B, lower 4 bits to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(0.1)
 MESSAGE = b'\x43\x04'              # Set PIC port B, lower 4 bits to 0x01 (Relays 3 on)
 set_relays(MESSAGE)
 time.sleep(0.001)
 readB()
 MESSAGE = b'\x43\x00'              # Set PIC port B, lower 4 bits to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(0.1)
 MESSAGE = b'\x43\x08'              # Set PIC port B, lower 4 bits to 0x01 (Relays 4 on)
 set_relays(MESSAGE)
 time.sleep(0.001)
 readB()
 MESSAGE = b'\x43\x00'              # Set PIC port B, lower 4 bits to 0x00 (Relays off)
 set_relays(MESSAGE)
 time.sleep(0.1)


